(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    158977,       3191]
NotebookOptionsPosition[    153325,       3104]
NotebookOutlinePosition[    153745,       3121]
CellTagsIndexPosition[    153702,       3118]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bf0e32a9-4d4a-4c28-b525-ab29b9afdd91"],

Cell["Chapter 8, Section 8.7, Figure 8.7", "Section",ExpressionUUID->"a71c017b-62b1-49b8-ab5c-8e7aaf0a0fd4"],

Cell[TextData[{
 "Set the colours for each plot. First order resonances will use ",
 StyleBox["color1;", "Input"],
 " second order resonance will use ",
 StyleBox["color2", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8706886125517807`*^9, 3.8706886208470783`*^9}, {
  3.879326645518285*^9, 3.879326704748672*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8a6894a7-971d-43c1-8f65-ad424bf821a8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8706884723044577`*^9, 3.8706884767572603`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"676eeb4c-9ed1-4d0e-912e-c53fc32779c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.870688484124298*^9, 3.870688503351976*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"566e010d-cd36-4f30-bb71-2ae038829cfe"],

Cell[TextData[{
 "Input the data on first-order resonances from Table 8.5.  For each \
resonance we input the coefficient of \[Lambda]', the coefficient of \
\[Lambda], the value of \[Alpha] = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "/",
 StyleBox["a",
  FontSlant->"Italic"],
 "', the value of \[Alpha]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", 
     StyleBox["d",
      FontSlant->"Plain"]], "(", "\[Alpha]", ")"}], TraditionalForm]],
  ExpressionUUID->"c7bb31da-c29e-4804-9653-56b98b4c37e1"],
 ", and the maximum value of the eccentricity in the plot (0.3 in this \
case)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1fc8515c-fe1a-4ddf-bdd9-fb617a1bf6a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"first", " ", "=", " ", "\n", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "0.629961", ",", " ", 
       RowBox[{"-", "0.749964"}], ",", " ", "0.3"}], "}"}], ",", " ", "\n", 
     " ", 
     RowBox[{"{", 
      RowBox[{"3", ",", " ", 
       RowBox[{"-", "2"}], ",", " ", "0.763143", ",", " ", 
       RowBox[{"-", "1.54553"}], ",", "  ", "0.3"}], "}"}], ",", "\n", " ", 
     RowBox[{"{", 
      RowBox[{"4", ",", " ", 
       RowBox[{"-", "3"}], ",", " ", "0.825482", ",", " ", 
       RowBox[{"-", "2.34472"}], ",", "  ", "0.3"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8790749173453283`*^9, 3.879074917351634*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"ccb4d648-554d-4faa-8d2f-f306288f052f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "first", "]"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"2df5d603-6142-4dbb-84f8-b6efa9274a8f"],

Cell[BoxData[
 TagBox[GridBox[{
    {"2", 
     RowBox[{"-", "1"}], "0.629961`", 
     RowBox[{"-", "0.749964`"}], "0.3`"},
    {"3", 
     RowBox[{"-", "2"}], "0.763143`", 
     RowBox[{"-", "1.54553`"}], "0.3`"},
    {"4", 
     RowBox[{"-", "3"}], "0.825482`", 
     RowBox[{"-", "2.34472`"}], "0.3`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8790749361999073`*^9, 3.8790753510500517`*^9, 
  3.879326722437752*^9, 3.879328596465907*^9, 3.879328774890432*^9, 
  3.8909871032238207`*^9},
 CellLabel->
  "Out[4]//TableForm=",ExpressionUUID->"0c9c6d5c-c355-4033-9d04-4a6ee026614c"]
}, Open  ]],

Cell["\<\
Now do the same for the second-order resonances in which we are interested.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bc4f5443-dd6b-4d84-84be-d9c6b52c360f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"second", " ", "=", " ", "\n", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "0.480740", ",", " ", "0.287852", ",", 
       " ", "0.3"}], "}"}], ",", "\n", " ", 
     RowBox[{"{", 
      RowBox[{"5", ",", " ", 
       RowBox[{"-", "3"}], ",", " ", "0.711379", ",", " ", "2.32892", ",", 
       "  ", "0.3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.879074950675625*^9, 3.879074950684679*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"60640f2d-2c31-4d60-ad33-4c8bca8fc4b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "second", "]"}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"9053de2c-c131-4f27-91b6-4881ecefff1f"],

Cell[BoxData[
 TagBox[GridBox[{
    {"3", 
     RowBox[{"-", "1"}], "0.48074`", "0.287852`", "0.3`"},
    {"5", 
     RowBox[{"-", "3"}], "0.711379`", "2.32892`", "0.3`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.879074967939395*^9, 3.8790753511128693`*^9, 
  3.8793267300433273`*^9, 3.879328596520406*^9, 3.879328774933119*^9, 
  3.8909871033044443`*^9},
 CellLabel->
  "Out[6]//TableForm=",ExpressionUUID->"c0f47ea9-eb67-4f65-ad00-68490bc46193"]
}, Open  ]],

Cell[TextData[{
 "Define a function, ",
 StyleBox["FirstPlot", "Input"],
 ", that will do the plots of maximum libration width (based on the pendulum \
model) in the (",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["e",
  FontSlant->"Italic"],
 ") plane."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"18b5b74b-89d0-422f-a4b8-51be14f8393c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FirstPlot", "[", 
   RowBox[{"mass_", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "j1_", ",", " ", "j2_", ",", " ", "\[Alpha]_", ",", " ", "afa_", ",", 
      " ", "emax_"}], "}"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"crn", " ", "=", " ", 
       RowBox[{"Abs", "[", 
        RowBox[{"mass", "*", "afa"}], "]"}]}], ",", " ", "evals", ",", " ", 
      "p1", ",", " ", "p2", ",", " ", 
      RowBox[{"a", "=", 
       RowBox[{"5.20336", "*", "\[Alpha]"}]}]}], "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"evals", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"ecc", ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "ecc", ",", " ", "0.001", ",", " ", "emax", ",", " ", "0.001"}], 
         "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"plus", " ", "=", " ", "\n", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", " ", "+", " ", 
            RowBox[{"a", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"2", "/", "9"}], ")"}]}], "*", 
                RowBox[{
                 RowBox[{"crn", "/", "j2"}], "/", "#"}]}], " ", "+", "\n", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"16", "/", "3"}], ")"}], "*", "crn", "*", "#"}], 
                 "]"}], "*", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"crn", "/", "27"}], "/", "j2"}], "/", "j2"}], "/", 
                   RowBox[{"#", "^", "3"}]}]}], "]"}]}]}], ")"}]}]}], ")"}], 
          "&"}], ",", " ", "evals"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"minus", " ", "=", " ", "\n", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", " ", "+", " ", 
            RowBox[{"a", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"2", "/", "9"}], ")"}]}], "*", 
                RowBox[{
                 RowBox[{"crn", "/", "j2"}], "/", "#"}]}], " ", "-", "\n", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"16", "/", "3"}], ")"}], "*", "crn", "*", "#"}], 
                 "]"}], "*", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"crn", "/", "27"}], "/", "j2"}], "/", "j2"}], "/", 
                   RowBox[{"#", "^", "3"}]}]}], "]"}]}]}], ")"}]}]}], ")"}], 
          "&"}], ",", " ", "evals"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"plus", ",", "  ", "evals"}], "}"}], "]"}], ",", "\n", 
        "      ", 
        RowBox[{"Joined", "->", "True"}]}], "]"}]}], ";", "\n", 
     RowBox[{"p2", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"minus", ",", " ", "evals"}], "}"}], "]"}], ",", "\n", 
        "      ", 
        RowBox[{"Joined", "->", "True"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Show", "[", 
      RowBox[{"p1", ",", "p2", ",", 
       RowBox[{"PlotStyle", "->", 
        RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2.4", ",", "4.7"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.3"}], "}"}]}], "}"}]}]}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.879074983436288*^9, 3.879074983444127*^9}, {
   3.879077236475176*^9, 3.879077243761465*^9}, 3.879077277362809*^9, {
   3.8793267738132763`*^9, 3.879326786953557*^9}, {3.879326860677931*^9, 
   3.879326902826364*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"a6ac6436-de02-45c4-bafd-94219fc5517e"],

Cell["\<\
Do the plot for the 2:1 resonance.  The first parameter is the mass ratio of \
the perturber (Jupiter).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"58546064-1781-4419-b61c-a03b3c736324"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p21", " ", "=", " ", 
  RowBox[{"FirstPlot", "[", 
   RowBox[{"0.000954", ",", " ", 
    RowBox[{"first", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8790750077777147`*^9, 3.8790750077846203`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"8b97393a-8b50-4158-9d28-ccedaf0ddd5d"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHk8VVsfxqXR3m5XE5WbRk3qldt0k95npShNNNDwaro3bpPG26zxdjWJ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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcjekbxhvS9DRhxh5lRMoYu5A0XS9ZhvzsW2lI2qYkKiQpIbJMtmxR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       "]]}}, {{}, {}}}},
  PlotStyle -> Directive[
    RGBColor[0.368417, 0.506779, 0.709798]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{3.3359637675089995`, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.879075009842767*^9, 3.879075351787456*^9, 3.8790772875359173`*^9, 
   3.879326799983136*^9, {3.879326864703061*^9, 3.879326887941758*^9}, 
   3.8793285971491632`*^9, 3.879328775565909*^9, 3.890987104370658*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"111fe7d2-cde3-4d6b-ad59-125709f1f65d"]
}, Open  ]],

Cell["Similarly do the plot for the 3:2 resonance ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c47d9196-1484-428b-a8c5-8b8dd4cecfd3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p32", " ", "=", " ", 
  RowBox[{"FirstPlot", "[", 
   RowBox[{"0.000954", ",", " ", 
    RowBox[{"first", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879075024683065*^9, 3.879075024689714*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"9d323f40-3bfd-464d-ba73-a92a199557c7"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcTfn/xxO/Qcw41hZkS/YlTaLB60xJomwpokikTUMlhWQrpNAyiTbt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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcTdsbxuO6ZGht89BFSld1TdeQOc9CijKlfpmSNCikQki6DXJFSSgi
mpGoNGgmzXVO0zknY3LLzTyEiwyF39m7vfY/fdaH1l7rfd/n+zw7TVvXlQ5d
VVRUxnVRUeF/cprZ6d2O9aIdie8VS21XIDbb7Hiznpq4tkH4iUVX3XoQ+s17
y3X3UCf4X26LqdxFxH93g0byghkHswndNzDF+JGnO1ZmRfr+8y/7/x5Y2UXh
bdmFo3tfjJmkmuSFoD2hjmlDOPH3fYFfvmw4qcvROU3Lg8Nd9mPv6JxJEfoc
9RL2O4A+fmH/KwVH8xb36To24CBWfDznXmzMifsfwtpiiS9ZxtFZ1yp3F0QH
ou/s/HAVc456Cu87gt8PWK9osORozsi/X5nlHEVEtH1pzRr2/mNYSP2HdLXi
6LnSUak7nI5DbtC6+9R6dp4T6DVzjdZ5a442fhVeiOy5TbexgRPvGwafnPdS
T+X6t4kPtbv7nUSTb9oOO+U6XzjvKQzc+/3nr8r1WvvZ/I6obXpe52zNzn8a
aiFb82KU74s4IzwYbf7OLNGK3ScCW+cuGRy8jqMNtZ/NWy6cRZKKYZTZWlbP
c1AxvZXbvpqjw7pZkvHpkRi3RnY0ZBVHc4X7RmF7VntqX+X9V88UNkTaO49p
+y3Y/WOgeWmy5OlKji6ZfniezZMYyCJuZlIzVo9YBD7U+XJ8OUdfm/EVjEVq
j3+MGpey+sRh2q4/h2su4egR52ftie/jUOi2tWCjCUcfCPWKx9FRjUbRizg6
NmDw/drP8QiqbUxoMGL1O4+dumrpAxdytCp2YdaH7+cxddCtocsWsHpegMkB
w90B8zi6VVmtod0u4n23fcuKwOp7EdWPDvbvMOBor7vxbga9EpDR2Ko1Yw6r
dwJc7Jvku2Zx9DJ/3b6XcHw8ccicwep/CfXO64d8nsZRE367wYnQ32+sPluf
9SMRaonq4X5TOPqSL/fwy1CZ3DtVOon15zJmtmj6Df6To4HK6sm0rsDVvLem
wwSO3hf6dQV+TtWxWeM4qmcVUvxJNwlmIRv69R7L+peEqhIDT1s9jkqUu6lP
TEb4gDst13VYP5Ph9fzTSvUxHN18/I0X9FOwZYi21FOb9TcFvZ3fLf5Hi6PK
wymvfBXR42fKDTVZv68i/6nj+hQNjlooh0fZUqQEX3ypPpL1PxVmvxL3wOEc
Pa+s3t34VByuqf3Qoc7mIRWuURZ2O4Zx9OP3Wx4vxqRBcswh/+UQNh9p2LPR
4KPDYI4aBvEDkIYJphd+fTyQzUsaxv2r+sx+AEfDhgoXQv3yQyHP+7H5SQel
qm0ufTn6WDheOhIk6PeFcFTY7n06Fh8pveuvxtEpwpOBrvMH0f592Hxl4Pqb
OBrfi6P+hVLlBGWg1+17ddN6snnLwIjNox9X9+BovbL7ypogB207Hbqz+buG
hhnyXSq/cnS0sOE1rHlp2Bz5C5vHa8h1bEs06MrRnU58AzJRtTdO0qTC5jMT
jqtGTTvwk9CST7rKDmfCudXu6R8/iDivWTgi9ZHXdxA6oPOAuHbhYqt3OxHn
NwvhSeP0x30jVDhdZRZO+R469+ALEec5G/N/mg8P/kxoeuTbhHLTbFy+sySJ
thFxvrPx6rWFYdtHQrsKF85GRMyOxuQPRJz3HOg8kzk7/kfoyk4AImDpzTda
7xmfc6DflLaq+S2hcfx1b+WgtY3GR7cSUQ+5mNmhK7F5Q+h//HarcxHY16R4
9Gsi6iMXS1ISAp6/JHQ+P/4PctF7jlP/qy+IqJc8HDp5a92e54Se4MfXOg97
j6xaP+8ZEfWTh9W2f/VVe0rov558Q/IQOueDS8NjQg8LesqHUdjBHYkthE4S
Bjwfu+O0B3kq/aVTX/lIl9xfseQRoX4nFyhHJh+vvss0RjUTUW/XMXSsuden
fwiVawkNhsXZcpvqh0TU33V8skqpON9IqCZP/zfX0T0x8Yr3AyLq8QaOmezs
sbaB0O28PNxuoGePR7en3SeiPm9AT7Wl36B7hBbx3f1wA7uN/bM+3iGiXguQ
0P644PZtQvt1ChIaqoZjcm4RUb8FiHL5+OxsPaFC+b4WwKBk409fBRH1fBPP
4oiTo5xQ4XheN2E6LmzEchkR9X0Tdvtif5tRR6iK8BQiSqd9vVYtEfVeiCul
ns1qNYReKjdVKroQHx1I9Lcq5t+FkGjnnHwuJXSFUo39/QsxNTG48K6EiDwo
hE9m9m+VlYR+4d2ntBD217bH51YQkQ+FaFjc0yKpnNAYdV4QRTj09KFeTBkR
eVGE0vU2midLCV30iG9wEfS8+08PKiEiP4qQkHTQcX8xoe8S+AMqyb5/w1XP
IiLypAhqW5f3di8k9DR/Oqlyf5OhHi43iciXIqwYGfTf5gJCqXK4FvcphubF
gD2bbhCRN8Vo7NPxi/11Qp+38xcuRkfo4zDbfCLypxha80x1bPMIPVYsCBh1
wcY5trmEduKyGEOG/TC0zyFUuK6sGLbrYqSblHmnk0/FULdyNtqSRaiwXf8S
GG1OynTJJCKvSvBTljXI/RqhAo7MS5B+7o2dZwYR+VUCvWUFkX7phHbGhxIs
j4otPJxGRJ6V4IzBb9ITqYQKOLhbghGncrPPXSUi30owOWRQQEIKoT68nIeW
4sJKhX5GMhF5Vwq3AZFFN5MI1REEVIrm2+N0a66wvFaKyTPnOz64TGidEC9K
ETg/wetlIhF5WApTvYmbvl0idA8vh4elyNPO0uytXHfysRTPZmkmD08gVIMf
55FlaOxr3X3iRSLysgwf823Hzr9AaAU/fjZlcA4br255noj8LINazzLZlnhC
Xfn2xpahY+f0pb5xjKdlCH8XEXwqltAhguDLYDtZ7VhyDONrOT5bZawsiyb0
Jn887XJ0NObWP4xivC1X+oVFv8+RhDpu4p9y2A670bNfJONvOX5I9PPHniOU
D09KwqLZrbu28VnG43KUFPw13y6CUJ6OHi/KYX/n3UDfM4zPFUgdm38m8jSh
1kJArUCm3dy6/HDG6wpY6/+b0XCK0O4CoCrw2mSg0beTjN8VmKC96IC6cs13
Y2BKBZy+tjnPDmM8r8B/UdE/rEIJFdLd2wr4bC6f7nOC8b0SagM+DY47TugP
Xm6TKuERkxdRdozxvhJJxleKXoQQepEf5x2VcLW0CSQhjP+VKB7m8WHKUUKX
dV4Y98pOtq8JZn5QiTDrjbG+Rwht49vxqRJnYgJaEoKYP0jw4GVuYV0goVH8
dadLkKmbMv3LYeYXEvheH2msqVwbCQWU4OIW6RuTQ8w/JNBb6P7HrgBCWwV7
kOByeEt79EHmJxI01LfYVP1N6Cke7+0SrPc2XP35APMXKYYPv988WrmeKzRE
ih8ae7+u8Gd+I0Xv+z9jvPcT+pTHq7cUbTZL7iT5Mf+R4nvgvNMPfAk9KuBP
iln1ZU96KdcCrh5JYbis5MYsH9KJl65VmHBGR2OrN/OnKrRIWlTP/UWoIN8F
VZBveL23xov5VRXeTZ25/ec+QgV5/F2Ffq5lbybtY/5VhYDtIa32noR2jl8V
BtWd3nF6L/OzKkye89Sj2oPQ23x7VasR5Oej0sWD+Vs17rq4qk7bQ+hffPkW
V6O1piRk627md9XQtAw+Gav8XvtdGMBqNEY3Db3nzvyvGgeGyodyynVNtfDg
TJtnmNFO5ofV6Dvha6D3DkJ3hfJArcE7+y3tWduZP9ZA5/nbx2/dCB0hDHSN
Mn8kG+m5Mb+swTZVqYadK6FlwudVDfxHubhGujD/rMGfm8qm3ttG6DYep4oa
6Eq+uwzYxvy0BqdijUcsdyZ0kCCQWmy9eHtu0Fbmr7V40tKoqNhC6A0eB5a1
mJYedq/bFua3tdiUNG35/M2EOgifX7XYkPBD39eJ+W8tRif+caTAkdA+nYLD
5OZvK75vYn5ci8Fn0/znKNfCuKjXQYOGjvZyYP5chzkLn068bk+o0A6rOvTU
/ZDQYcf8ug7fHLoFGSjXnZ9ndUh333TP25b5dx088xxDCjcSKmzXVIfmg6uv
dt3I/FwGz95B0xfaML3LUGJhrnNoA/N3GXQW9PCusmb6l0H3wI9ZnDXzexni
gk6sN1/PeCDD1OCRT8KtmP/LULzrp6xxHeODDBpPQkdprWN5QIZynTn1jmsZ
L2S4+efa58lrWD6QISzUbMPH1YwfMjh7B0yfvZrlBRlmXLN127+K8USGLgGm
PaWWLD/IsExxpUt/S8YXGWI/ta5e+z+WJ+ToV+dH4i0Yb+Roz1RovjZn+UKO
8l1mJ/TNGX/kkC5y3eCzkuUNOQzqow5JzBiP5DAZaaE20IzlDzn0Qru9sV7B
+CTHxrYxOpeXszwiB7Gbkv9pGeOVHMZG8ZfmLWP5RI4Ta9+3Bi9l/JJjW/yZ
4IYlLK/I0eo07IDOEsYzOVynvJW7m7L8Iod5RcTuYhPGNzkaR0Vu72vC8owC
fdw8iq0XM94pED8w1Sl5Ecs3CuhEVNp1GDP+KfA1wzjD1JjlHQUCZl6zPGvE
eKiAj9appa8WsvyjwEj/3eGzFzI+KhB4qGnKEUNChXEOUWDGLiuthwsI7fzz
gQJ2kXttJyxg+UiBM3alH3zmE9oZHxVYpF91Wz6P5SUFNgWMUNWex3iqgEa9
aeBuyvKTAmEnnq2TgPG1HhcM/L2Gg+WpelQZpb9ynct4W4+fQ3omlhiwfFWP
/wMA6of9
       "]]}}, {{}, {}}}},
  PlotStyle -> Directive[
    RGBColor[0.368417, 0.506779, 0.709798]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4.06053566978118, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8790750256791983`*^9, 3.879075352072461*^9, 
  3.8790772941856956`*^9, 3.879326915688162*^9, 3.8793285974140377`*^9, 
  3.879328775655589*^9, 3.8909871050037603`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"4817b0b0-42ed-40b9-b7a7-229d60a77da4"]
}, Open  ]],

Cell["... and the 4:3 resonance.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c8dacd4f-9e35-4976-9a6d-7ad77922a08c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p43", " ", "=", " ", 
  RowBox[{"FirstPlot", "[", 
   RowBox[{"0.000954", ",", " ", 
    RowBox[{"first", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8790750373436747`*^9, 3.879075037349831*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"6844621b-0d64-4b36-be97-213a4b348464"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHdcFEcUxxEBFdC4Swmg2BVsKKIS1PAbLCQmGAUJETUGC4ItokYkiGKJ
DcWGFSkqSO9dEClHr3eHsWHFAtgxIDY0s7s3+w+f7weYm5n33ve9vcHL1ju5
q6upqY3ppqYm/IxJefy2MseYfI5tU85ZNg8BOyyu395koGI37Joh//ZOD33y
cfvqK38FeaLJZ8phayc91e+9MDJLdv7cE55s1U/64aHvX9B+XmV3OpRX/b0P
tn8MCj64mid/t46w7Jngh0faHl4xM3nV/+9A3rT2syfNeDLt/tzA03/uwjp3
k6qsvjzxE9f7BzVRhfFLv3Akd7au+uh9e/HRI6HT5zWnWn8/LAL1zSY/4siU
jArvq+EBGDr7n83atzjiK37eIUyR2ToeknMkZ8Ce5445h6Fd3lKxppJTff5R
xNv+qL9GxpGQkkEpGz2PwawwIdT1Kqfaz3GE/uQc1jeXI3c+iB+IpSOdC7yy
ONV5T8B/qIGHWzpH+o27O0xr50nU5uVsrUrhSJ6431PoHbnMOzSJIwtXTBVW
RNq78OSqBLb/MwhtfnVtVjxHgs+KD6Zu2OSnEcfOEwyjgkn1XTEcuV3XOf/R
pXO4cXHbzFGUpfsMgXrRktW7ozlirOHSZ2xaKHTHH8/pTvmyeN4wfB7+15qo
KI4ssBEXhPu7He4eUez857G1XddwBmUH6wN2bk/Oo6XNZsXkKHYfF6D797JQ
W8ovHIUbvIBThxetdI1i93MRLaN7J/9D+dDa5k+xbZTNPkZfpdwo3lcEjpxd
flmT7mf0PsNbdZ0R8B8k27ogmt1fJFoUy1MzKVdfmJX1X1ckZns/J/1j2H1e
QoY8cfxBymvobRlpRKF6YtzFbrHsfqPQS8dYsZ2y9o0Ir++1o+Fkv0lHPY7d
dzR+X/0wPYBynHDcvjH4fEX9e6N4dv8x2Jj+1SyO8k/CcoaxmJxzR50ksHjE
4p6Rhsctys+E6+4fh90uXzs3J7L4xEFruusyAxrfAHp78iHxcP05YmE25Vti
vOJRibMhi5I5MnLxkeIO8wSsXPnHs24pLH4J2Lfjhk4c5Uq6msm4RFxP71U3
P5XFMxET6sPUv1JedeylHyYlwTp7lX98GotvEp7qfzF1pflHN0ePnIxxEU55
PTJYvJOxN2WddTZlZ5o8NKT4ctZks0cmi38Kci2iXY1oPkfS27sRkYJufWJq
KrNYPqRAMV6WvTWbI+1d13xaR6SitdVfyyKH5UcqJl7tF/WA8syDQgKkQhGw
fE/QZZYvqTDwP3rCntbPCSPxQIj0Ny/9kMvyJw2LTjzslZjHkcfi9tIwsM9+
F7crHBGXa0vDhH7N4Xr5HLESn3RYHUhvLMtn+ZWOlVt91Hxpve4urKIZlA67
pj2aYwtYvqVDd9+DpvuUG2j06Z1g7m6rY8cLWf5l4Ds1Wa9ZRRwZKi6YgQ+m
bvadRSwfMxD29He72GKObPIUApCJmgn7OhbKWH5m4vQqgyW6JRyRdZjTCGfi
pVaMd34Jy9csTLk+beqfpRzRkzaISrl5zIAylr9Z6DjK5dZRFndXkYXnDs3r
tpezfM5GlcP9wrEVHEkLfR1d9nM2PBR/ptypYPmdjZKl9lMOUp+piwemv/ee
s9imiuV7DgJ9w/SbKTtJAsTtfruXnqhm+Z8D9SYvO7sajlwUjnstB249tdJf
1rB6uAydE1qZZ2s58lZYbsFlbLrgaj+rjtXHZWg80Vr5hvJ0If0bLyNr4US9
c/WsXnJROmjYnFnUv8eF9F2SCwvfCXqv5ax+clHS0bDijIIjTb5CQHJhkB1k
Z6fkyAGxnvLgdY+LbaVsKSZ4HjJ7q5871sDqKw+Xe4z61uYaR3aenEFTJg/f
ebqZPrjG6u0K9m88mLj3X44ohogBxvyO8PIx11n9XUGl3fk1SsqDBfu/vIKn
E8+d3XKD1WM+1jvGO/a/yZENQnl45WNba0dQ4U1Wn/lwd4lzW0H7TZEQ3f/y
wdt2y+lxm9XrVRQ+nhocR5mTChJzAiJ6zGlk9XsVs5X71V5TFq/vw1VoTJ6x
5+gdVs8FeOk//pTlXY6I2/MrQMjcDCvlXVbfBXhzyXrJxnscUROfQmT7mBvy
91m9F8J5zodFqZRjyn6mFV2IL7cGjZ/3gNV/IfokGge9ojyPViO/uxB9by/d
c+gh80EhTBJ8e4xq4sh7ofuUFGL07y3G5U3MD5SVlvnLaf89byIURBFmLnrQ
9vUR80URHH38c8495siPD4UAF8H4Qghn/YT5owj9ufIuBeU30cIGi5Bx6si2
tU+ZT4qw2H3/Ma1mjpwRdldVhFvPZk4538z8UoSx0a4+Ni0cITS5ZusWw7DH
YgdlC/NNMTpJU9bqVo60fBIOXAy1ibtz1J8x/xTDb/Z1x2DKR4vFAobxgk27
LZ9zRNJlMXodeDungrJ4XHkxWm1fpC55wfxUDIcv75PbKYvL8TIof0v9MeAl
85UMiQ2JfgNfcUTU0XwZDtzb65DxivlLhtzsazk/0nlGGh9kOOc2rvjOa+Yz
GfQCLVZ5veGIqIMbMgw7uSqpexvzmww7PbYcP0XZXyhnoxLobHtlMPIt810J
ptWusMmjbCYWUAkWytZ3OfzH/FcCn4mRy+5RrhfHixLYuJxatb6d+bAEVlm3
eLUOjmwRyuEuXX9Ctz+OdjA/lmDQm7BfBr3jyEAhnQeUQrFgZlPyO+bLUvzQ
d5cJOjlSLqSfWynK3zR31nYyf5bCT1Nz6+L3HFkvhPdCKdL2eEQ+e898Wood
8pC/fD5w5Fux4EvR6Gn5QvMj82sZutpSdIIoFwjbG1YG6zFRDQM/Md+Woefb
4JkJlD1WCk8Zjkwy+uO7z8y/ZSBfLg0toSwMT9SwaF5ZfXxuF/NxGZrO9Um8
TVmwo09rGaJutW90/8L8XI6/16g/eU15iTiglmNRXG5336/M1+UY9zm8vrsa
T7REQZWjb4PV7EDKkr/LUZPwzsuwG0+EaOgnleMU7/lDOGXJ5+W4fkar1kyd
J+J097ocA+/PVU+hLPm9Ak5HC5utu/Pki1BulhVoWHZtWwFlyfcVaDbSKrXX
4EmUkM4bKzB6Z31+rQabzytgviXW01mTJ79IB8bHRzpltylL/aAChgXrrrtp
8eSdEI6OCgz+ZlbwU8pSf6jEnWda/NoePAkTjmtdiSG+ZrZtlKV+UYmud8YD
vXvyxF68wEoUJs3L/EhZ6h+VQPfvu/n34skrsT1UQnPt3O7dtXlVP6lExJbO
vL2UTwl6/1SJnrURo7V1eFV/qcKdMcVOgZRtxYBUoX1jgWVfXV7Vb6pQcLpH
5XHKTwW9bq9CVaqmsUFvXtV/qmDbOXTIacqHRf1VYUNB9WOjPjwRdfWwCt7/
uC8NpizqRb0a2Y8XnOn3Da/qT9UIjNQNCKEslu+MajxNfjrZlL6/SP2qGs/6
OYSHUhbLY081LphfkJlyvKp/VSNi+uzIUMpS+lWjRCPazpTnVf2Msk3/kBDK
/wrh7VkDzXu9Mvrp8ar+VgPbwfIDwZS3Cdc3uwYWnnWmxvq8qt/V4Ndflnud
pjxcTMAaxEW/2GlgwN7HajBvV7lTEOXaGvHBXPN5j/oa8qp+WIMfBjdZHaa8
OUgQai3GTLw5U+dbXtUfa9HuechwP2VTMaFrMU97QayGEa/ql7VYEh3UtYNy
qfh6VQtXg9N6XZSl/lmLnzZcfu5jzJN1gk6Vtcge7Li3nbLUT+l6N9MfrTfh
iYFYIHU4EzRZ4zllqb/WIfD82Bb3fjzJF3TgUgfnkBdHHlCW+m0d/t1c9mlh
f564i69fdVi+vveYfylL/bcOLoP0Bs815YmuVHBI9jZvrKAs9eM6xOSELpw+
gCdiupjUY/7e4vA8ylJ/rodF45O4iQN5IoZjcT0Sv3HxS6Qs9et6KG+76Y8Y
xBPp9aweafPnbwqjLPXvenT/7++zhoN5Ii53vx7BJwbtO0xZ6udytPscn6Y1
hNW7HBn2JrnbKEv9XQ5TXXW1jiGs/uUIIEF91g7lVf1ejtZSw6dNQ5kP5DB/
dm2v6zD2/i1HlKdBW/0w5gc5zq8ZONx+OK+aB+Q4E2gz9Mpw5gs5rtyOfW45
glfNB3LMUmZujx7B/CFHo8fFO/3p+7w0L8jxQiND87gZ84kcmgEWH7XMedX8
IMeoeb/mbjVnfpFjyKg19m8oS/OEAtXuaWErRjLfKLCidq3sJmVpvlBAHtOY
4TCK+UeBpqvYVEhZmjcUCHa59cVqNPORAsu/a/ktmrI0fygwNzl+u8kY5icF
HAOWbQqkLM0jCqwz/Xmy2ljmKwVeTo8o30hZmk8UOLw4xuzJWOYvBZKcT7v8
ZsGr5hUF/gxPcK60YD5T4O7UYUOmjuNV84sCxpk2BQnjmN8UWD3UfMyA8bxq
nlFi+dhRq46MZ75T4kNPX281S1413yhxxs/ReYMl858S1g9a1ZsoS/OOEmsG
+O1ymsB8qMS6TNJQPIF936LE2Jz1HROsmB+V+LWetF6kLKbzESUcpjxP4ify
RPr6QAlb+SX7XZSl+UgJ/W7RKW2UpfFRCZ/rw166TeJV85ISFe3On+snMZ8q
wYWsvWc7mVfNT0poxJ4PSpzM/NqAxyeH9+9vzavmqQb4bB3nE2DNfNuA99zb
6PeUpfmqAf8D3St9zg==
       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcjekbxrP+aCzPGHsM2UkaymTtemgUpURkC1lC2Yosc6YQiYhKkjUt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       "]]}}, {{}, {}}}},
  PlotStyle -> Directive[
    RGBColor[0.368417, 0.506779, 0.709798]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4.406489944466901, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.879075038204843*^9, 3.879075352173553*^9, 
  3.879077297386649*^9, 3.8793269187467813`*^9, 3.8793285974867573`*^9, 
  3.879328775946101*^9, 3.890987105222928*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"d263a809-e96a-4e6f-8888-0450375b01a1"]
}, Open  ]],

Cell[TextData[{
 "Now define a function, ",
 StyleBox["SecondPlot", "Input"],
 ", to do the same for a second-order resonance."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"17ffc0b3-27b0-490f-9b92-d34f770bb822"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SecondPlot", "[", 
   RowBox[{"mass_", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "j1_", ",", " ", "j2_", ",", " ", "al_", ",", " ", "afa_", ",", " ", 
      "emax_"}], "}"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"crn", " ", "=", " ", 
       RowBox[{"Abs", "[", 
        RowBox[{"mass", "*", "afa"}], "]"}]}], ",", " ", "evals", ",", " ", 
      "p1", ",", " ", "p2", ",", " ", 
      RowBox[{"a", "=", 
       RowBox[{"5.20336", "*", "al"}]}]}], "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"evals", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"ecc", ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "ecc", ",", " ", "0.001", ",", " ", "emax", ",", " ", "0.001"}], 
         "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"plus", "  ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", " ", "+", " ", 
            RowBox[{"a", "*", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"16", "/", "3"}], ")"}], "*", "crn", "*", 
               RowBox[{"#", "^", "2"}]}], "]"}]}]}], ")"}], "&"}], ",", " ", 
         "evals"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"minus", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", " ", "-", " ", 
            RowBox[{"a", "*", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"16", "/", "3"}], ")"}], "*", "crn", "*", 
               RowBox[{"#", "^", "2"}]}], "]"}]}]}], ")"}], "&"}], ",", " ", 
         "evals"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"plus", ",", "  ", "evals"}], "}"}], "]"}], ",", " ", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"Directive", "[", "color2", "]"}]}], ",", "\n", "      ", 
        RowBox[{"Joined", "->", "True"}]}], "]"}]}], ";", "\n", 
     RowBox[{"p2", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"minus", ",", " ", "evals"}], "}"}], "]"}], ",", " ", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"Directive", "[", "color2", "]"}]}], ",", "\n", "      ", 
        RowBox[{"Joined", "->", "True"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Show", "[", 
      RowBox[{"p1", ",", "p2", ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2.4", ",", "4.7"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.3"}], "}"}]}], "}"}]}]}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.879075053978673*^9, 3.8790750539849854`*^9}, {
  3.879077303271133*^9, 3.879077303763915*^9}, {3.879326948757967*^9, 
  3.879326998317049*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"fe52e49f-f573-455d-bd01-f38f688802a6"],

Cell["Plot the maximum libration width of the 3:1 resonance ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9d270fd6-51d9-43e5-bee3-ae09ad0e0198"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p31", " ", "=", " ", 
  RowBox[{"SecondPlot", "[", 
   RowBox[{"0.000954", ",", " ", 
    RowBox[{"second", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8790750706438932`*^9, 3.8790750706529922`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"b08124cb-f5ae-41c8-b8cc-36bff68dd990"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcjukax8ODpEWlRaXRroUWkja/Z+yJLDVkbE22ZqzhZCnbUMhSJLKl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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlczWn7x9OJScZaeqpJxlqWjGXI9utzQvwoSoNJiIdEjC2hQZYMIluW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       "]]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2.500962693374802, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.879075072025215*^9, 3.879075352271426*^9, 3.879077307956233*^9, {
   3.879326957157856*^9, 3.879327001510215*^9}, 3.879328597570787*^9, 
   3.879328776059058*^9, 3.8909871054539003`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"40004610-6f65-4d7d-8231-0b5ee4621b25"]
}, Open  ]],

Cell["... and the 5:3 resonance.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b3c8fb06-b4a4-4520-9c7e-8498029db7f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p53", " ", "=", " ", 
  RowBox[{"SecondPlot", "[", 
   RowBox[{"0.000954", ",", " ", 
    RowBox[{"second", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.879075085839221*^9, 3.8790750858455667`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"d2ee28b1-eab7-4101-aa6c-539bd2b40dc0"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlYTVsYxpMh014iUsgQMisyRbwrUzJkiIRQrkhu6Za5yFBShEJmSVGo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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHdczt0bx7N6xDkho+xsWT0y8kQ+hzKyCxmRyCiyRUJGyIiMQqiHoqS0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       "]]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{3.699454015490531, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.879075086572472*^9, 3.879075352352745*^9, 
  3.8790773116621428`*^9, 3.879327005037376*^9, 3.879328597682241*^9, 
  3.879328776154894*^9, 3.890987105735991*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"d15afeaf-d1bf-4a3d-9b77-ff672a68e806"]
}, Open  ]],

Cell[TextData[{
 "Get the orbital period of Jupiter (in years) from the appropriate ",
 StyleBox["Entity", "Input"]
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290877447357`*^9}, {
  3.851429181268784*^9, 3.851429198443904*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"91260320-d68b-47f3-9e23-d7f9905789f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jper", "=", 
  RowBox[{"QuantityMagnitude", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Entity", "[", 
      RowBox[{"\"\<Planet\>\"", ",", "\"\<Jupiter\>\""}], "]"}], "[", 
     RowBox[{"EntityProperty", "[", 
      RowBox[{"\"\<Planet\>\"", ",", "\"\<OrbitPeriod\>\""}], "]"}], "]"}], 
    ",", "\"\<Years\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851424676643838*^9, 3.851424676647027*^9}, {
   3.851425891106358*^9, 3.85142589239612*^9}, 3.851429216132943*^9},
 CellLabel->"In[14]:=",ExpressionUUID->"acdaca2b-a2dd-46c6-8566-8f887068d58a"],

Cell[BoxData["11.8707400787671232877`8."], "Output",
 CellChangeTimes->{3.851429217438849*^9, 3.851429519261217*^9, 
  3.851429601014027*^9, 3.87907569710955*^9, 3.8790773157620907`*^9, 
  3.879327011241541*^9, 3.879328598107716*^9, 3.879328776561348*^9, 
  3.890987107555623*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"8ec59d34-24af-4c0f-b710-ec57d6e20a9d"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["semimajoraxis", "Input"],
 " to calculate the semi-major axis of a nominal resonance location."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"43620af5-0444-4077-9f8d-0ec50f76efd2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"semimajoraxis", "[", "ratio_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ratio", " ", "jper"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"2", "/", "3"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851424689871635*^9, 3.851424689880519*^9}, {
  3.8514267903377237`*^9, 3.851426804721116*^9}, {3.851427617860693*^9, 
  3.851427619088297*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"c2430dd3-566b-447f-b5a0-768482e46073"],

Cell["Select the resonant locations to be indicated ...", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}, {
  3.85142926663439*^9, 3.851429305588645*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7f390734-83a8-43bd-b47d-2a9fe86d6f82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"reson", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "3"}], ",", 
     RowBox[{"1", "/", "2"}], ",", 
     RowBox[{"3", "/", "5"}], ",", 
     RowBox[{"2", "/", "3"}], ",", 
     RowBox[{"3", "/", "4"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851427634449809*^9, 3.8514276510377083`*^9}, {
  3.8790756316146517`*^9, 3.879075660024365*^9}, {3.8793286573838043`*^9, 
  3.879328689609844*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"52cb5bf8-b18c-4abd-a07d-879945d0b0b2"],

Cell["\<\
... and calculate their corresponding semi-major axes (in AU).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}, {
  3.85142926663439*^9, 3.851429333654133*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"233fc2fe-d456-42ee-98eb-ea9fb89d0406"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"smares", "=", 
  RowBox[{"Map", "[", 
   RowBox[{"semimajoraxis", ",", " ", "reson"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851426820142808*^9, 3.851426831166012*^9}, {
  3.851426867961792*^9, 3.851426894482387*^9}, {3.851427153429881*^9, 
  3.851427159699313*^9}, {3.851427646213011*^9, 3.851427654517592*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"5f28e515-cfb3-4e14-bf8c-8312f07ffd7d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.5017142022180122744`8.176091259055681", ",", 
   "3.2781729831165155712`8.176091259055681", ",", 
   "3.7018546632204486751`8.176091259055681", ",", 
   "3.9712237563246570978`8.176091259055681", ",", 
   "4.2956218171153577894`8.176091259055681"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8514268996561832`*^9, 3.85142716557885*^9, 3.85142766261518*^9, 
   3.851429519322414*^9, 3.85142960107403*^9, 3.8790756641659203`*^9, 
   3.8790757073632097`*^9, 3.879077323342588*^9, 3.87932702157384*^9, 
   3.879328598151908*^9, {3.879328664475361*^9, 3.8793286936830177`*^9}, 
   3.879328776601863*^9, 3.890987108017646*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"d80108ca-e92e-483a-a0ef-353b0310a027"]
}, Open  ]],

Cell["\<\
Use these locations to define a set of vertical lines to be used in the final \
plot.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}, {
  3.85142926663439*^9, 3.851429380093533*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"052ba23a-3b69-4e29-a094-022129aef0b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lines", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", "0.3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"#", ",", "0.29"}], "}"}]}], "}"}], "]"}], "&"}], "/@", 
     "smares"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851424712343913*^9, 3.851424712347118*^9}, {
   3.8514276946282177`*^9, 3.851427734316949*^9}, 3.851427784386293*^9, {
   3.851427915456135*^9, 3.8514279160532703`*^9}, {3.8514279496537437`*^9, 
   3.851427950162444*^9}, {3.8514280230209293`*^9, 3.851428028086711*^9}, {
   3.8514280625886707`*^9, 3.851428070610867*^9}, {3.8790757310016327`*^9, 
   3.8790757719497967`*^9}, {3.8790765756584387`*^9, 3.8790765829010763`*^9}, 
   3.8790813917686462`*^9, {3.879081580019421*^9, 3.879081583688586*^9}, {
   3.879081902751264*^9, 3.87908190316614*^9}, {3.879327381400773*^9, 
   3.879327387563519*^9}, {3.8793274328050423`*^9, 3.87932743397472*^9}, {
   3.879327681384803*^9, 3.87932768261267*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"8317e7b7-c193-4bb0-aff9-e2a1906a91fa"],

Cell["\<\
Use these locations to label the vertical lines for each resonance.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}, {
  3.85142926663439*^9, 3.851429380093533*^9}, {3.879328466001522*^9, 
  3.879328482140506*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"475bc4ef-3615-437a-a97f-96ca954c67d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"linelabels", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"3", ",", "\"\<:\>\"", ",", "1"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"smares", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "0.285"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"2", ",", "\"\<:\>\"", ",", "1"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"smares", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "0.285"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"5", ",", "\"\<:\>\"", ",", "3"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"smares", "[", 
              RowBox[{"[", "3", "]"}], "]"}], ",", "0.285"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"3", ",", "\"\<:\>\"", ",", "2"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"smares", "[", 
              RowBox[{"[", "4", "]"}], "]"}], ",", "0.285"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"4", ",", "\"\<:\>\"", ",", "3"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"smares", "[", 
              RowBox[{"[", "5", "]"}], "]"}], ",", "0.285"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "}"}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.879076211768509*^9, 3.879076245827984*^9}, {
   3.879076616967733*^9, 3.879076617461293*^9}, 3.879076973909874*^9, {
   3.87908146366472*^9, 3.879081474955234*^9}, {3.8790815280591927`*^9, 
   3.879081543820314*^9}, {3.879081611714254*^9, 3.879081622541337*^9}, {
   3.879081786981866*^9, 3.879081842791151*^9}, {3.879082150490402*^9, 
   3.879082160401269*^9}, {3.879327053095953*^9, 3.879327120339727*^9}, {
   3.87932744630587*^9, 3.87932745534918*^9}, {3.879327504970327*^9, 
   3.879327514883574*^9}, {3.879327692500628*^9, 3.8793277043931026`*^9}, {
   3.879327752484386*^9, 3.879327762984967*^9}, {3.879327796631411*^9, 
   3.8793278035738688`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"69e5fd73-5d0b-4824-bd72-0234de337c59"],

Cell["Combine the lines and labels in a single plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8514282097047997`*^9, 3.8514282765267067`*^9}, {
  3.8514286882257032`*^9, 3.851428823164132*^9}, {3.8514288946824837`*^9, 
  3.8514289817400312`*^9}, {3.851429021596284*^9, 3.8514290260949697`*^9}, {
  3.85142926663439*^9, 3.851429380093533*^9}, {3.879328466001522*^9, 
  3.879328522206506*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8954b9d2-151f-43d9-87ea-1f5bf802a78f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"reslabels", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"lines", ",", "linelabels", ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2.4", ",", "4.7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.87907631059214*^9, 3.8790763337340384`*^9}, {
   3.879076640921981*^9, 3.879076689343392*^9}, {3.8790767314030027`*^9, 
   3.8790767548617487`*^9}, {3.879076822948854*^9, 3.879076824012454*^9}, {
   3.8790768612742443`*^9, 3.879076867527321*^9}, {3.879077119500328*^9, 
   3.879077157554727*^9}, {3.8790796204550457`*^9, 3.879079651549467*^9}, {
   3.87907974920651*^9, 3.879079764597327*^9}, {3.879080789361706*^9, 
   3.8790807902746363`*^9}, {3.8790813418889*^9, 3.879081355656774*^9}, {
   3.879081635635248*^9, 3.879081636008835*^9}, {3.8790822051000967`*^9, 
   3.8790822344529953`*^9}, {3.879082276139792*^9, 3.87908227754776*^9}, 
   3.8790967405725813`*^9, {3.879327722859687*^9, 3.879327727433214*^9}, {
   3.879328254655314*^9, 3.879328274346575*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"cfe516a6-24c4-48bc-a81e-67ffd45c6c09"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"016bf37a-0a82-4bf5-b24d-9d4e816c98a9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Semi-major Axis (AU)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<Eccentricity\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.851338850796014*^9, 3.851338856475478*^9}, {
  3.851339056483313*^9, 3.851339071079105*^9}, {3.8790751708185472`*^9, 
  3.879075193961151*^9}, {3.8790752823156977`*^9, 3.879075295960511*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"feca2ea0-92f4-4127-a038-e9f84722857d"],

Cell["\<\
Combine all the plots and resonance annotation together in one diagram.  This \
is Fig.8.7.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.879328318131419*^9, 3.879328341951194*^9}, {
  3.879328428877035*^9, 3.8793284386419983`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"58a9e2a8-3815-41a1-b2a1-5761ec077f67"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot", "=", "\[IndentingNewLine]", 
  RowBox[{"Show", "[", 
   RowBox[{
   "p31", ",", "p21", ",", "p53", ",", "p32", ",", "p43", ",", "reslabels", 
    ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2.4", ",", "4.7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.3"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"2.4", ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRangePadding", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8790751117459307`*^9, 3.879075111752182*^9}, 
   3.8790752470936747`*^9, {3.879075807801278*^9, 3.8790758298808107`*^9}, {
   3.879075869257606*^9, 3.879075908213176*^9}, {3.8790759517589207`*^9, 
   3.879075991807478*^9}, {3.879076023866468*^9, 3.8790760630419893`*^9}, {
   3.879076167459324*^9, 3.8790761680133047`*^9}, {3.879076262020084*^9, 
   3.87907630451385*^9}, {3.879076784039084*^9, 3.879076810542465*^9}, 
   3.8790771120913763`*^9, {3.879079602304029*^9, 3.879079603037922*^9}, {
   3.879079734216851*^9, 3.8790797385378103`*^9}, 3.87907978283854*^9, {
   3.87908101061133*^9, 3.8790810547861547`*^9}, {3.879081106417082*^9, 
   3.879081135831476*^9}, {3.8790823764594097`*^9, 3.879082416962049*^9}, {
   3.879082457879746*^9, 3.87908246128356*^9}, 3.879096642030973*^9, {
   3.8793282851793957`*^9, 3.8793282980916243`*^9}, {3.879328367327785*^9, 
   3.879328400512635*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"c4de6d64-0cc9-4ae8-a84c-c3fba4b5f453"],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9mHlcjukax8ODpEWlRaXRroUWkja/Z+yJLDVkbE22ZqzhZCnbUMhSJLKl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        "]]}}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9mHlczWn7x9OJScZaeqpJxlqWjGXI9utzQvwoSoNJiIdEjC2hQZYMIluW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        "]]}}, {{}, {}}}}, {{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9mHk8VVsfxqXR3m5XE5WbRk3qldt0k95npShNNNDwaro3bpPG26zxdjWJ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        "]]}}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1mHlcjekbxhvS9DRhxh5lRMoYu5A0XS9ZhvzsW2lI2qYkKiQpIbJMtmxR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        "]]}}, {{}, {}}}}, {{{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1mHlYTVsYxpMh014iUsgQMisyRbwrUzJkiIRQrkhu6Za5yFBShEJmSVGo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        "]]}}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9mHdczt0bx7N6xDkho+xsWT0y8kQ+hzKyCxmRyCiyRUJGyIiMQqiHoqS0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        "]]}}, {{}, {}}}}, {{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw9mHlcTfn/xxO/Qcw41hZkS/YlTaLB60xJomwpokikTUMlhWQrpNAyiTbt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        "]]}}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1mHlcTdsbxuO6ZGht89BFSld1TdeQOc9CijKlfpmSNCikQki6DXJFSSgi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        "]]}}, {{}, {}}}}, {{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1mHdcFEcUxxEBFdC4Swmg2BVsKKIS1PAbLCQmGAUJETUGC4ItokYkiGKJ
DcWGFSkqSO9dEClHr3eHsWHFAtgxIDY0s7s3+w+f7weYm5n33ve9vcHL1ju5
q6upqY3ppqYm/IxJefy2MseYfI5tU85ZNg8BOyyu395koGI37Joh//ZOD33y
cfvqK38FeaLJZ8phayc91e+9MDJLdv7cE55s1U/64aHvX9B+XmV3OpRX/b0P
tn8MCj64mid/t46w7Jngh0faHl4xM3nV/+9A3rT2syfNeDLt/tzA03/uwjp3
k6qsvjzxE9f7BzVRhfFLv3Akd7au+uh9e/HRI6HT5zWnWn8/LAL1zSY/4siU
jArvq+EBGDr7n83atzjiK37eIUyR2ToeknMkZ8Ce5445h6Fd3lKxppJTff5R
xNv+qL9GxpGQkkEpGz2PwawwIdT1Kqfaz3GE/uQc1jeXI3c+iB+IpSOdC7yy
ONV5T8B/qIGHWzpH+o27O0xr50nU5uVsrUrhSJ6431PoHbnMOzSJIwtXTBVW
RNq78OSqBLb/MwhtfnVtVjxHgs+KD6Zu2OSnEcfOEwyjgkn1XTEcuV3XOf/R
pXO4cXHbzFGUpfsMgXrRktW7ozlirOHSZ2xaKHTHH8/pTvmyeN4wfB7+15qo
KI4ssBEXhPu7He4eUez857G1XddwBmUH6wN2bk/Oo6XNZsXkKHYfF6D797JQ
W8ovHIUbvIBThxetdI1i93MRLaN7J/9D+dDa5k+xbZTNPkZfpdwo3lcEjpxd
flmT7mf0PsNbdZ0R8B8k27ogmt1fJFoUy1MzKVdfmJX1X1ckZns/J/1j2H1e
QoY8cfxBymvobRlpRKF6YtzFbrHsfqPQS8dYsZ2y9o0Ir++1o+Fkv0lHPY7d
dzR+X/0wPYBynHDcvjH4fEX9e6N4dv8x2Jj+1SyO8k/CcoaxmJxzR50ksHjE
4p6Rhsctys+E6+4fh90uXzs3J7L4xEFruusyAxrfAHp78iHxcP05YmE25Vti
vOJRibMhi5I5MnLxkeIO8wSsXPnHs24pLH4J2Lfjhk4c5Uq6msm4RFxP71U3
P5XFMxET6sPUv1JedeylHyYlwTp7lX98GotvEp7qfzF1pflHN0ePnIxxEU55
PTJYvJOxN2WddTZlZ5o8NKT4ctZks0cmi38Kci2iXY1oPkfS27sRkYJufWJq
KrNYPqRAMV6WvTWbI+1d13xaR6SitdVfyyKH5UcqJl7tF/WA8syDQgKkQhGw
fE/QZZYvqTDwP3rCntbPCSPxQIj0Ny/9kMvyJw2LTjzslZjHkcfi9tIwsM9+
F7crHBGXa0vDhH7N4Xr5HLESn3RYHUhvLMtn+ZWOlVt91Hxpve4urKIZlA67
pj2aYwtYvqVDd9+DpvuUG2j06Z1g7m6rY8cLWf5l4Ds1Wa9ZRRwZKi6YgQ+m
bvadRSwfMxD29He72GKObPIUApCJmgn7OhbKWH5m4vQqgyW6JRyRdZjTCGfi
pVaMd34Jy9csTLk+beqfpRzRkzaISrl5zIAylr9Z6DjK5dZRFndXkYXnDs3r
tpezfM5GlcP9wrEVHEkLfR1d9nM2PBR/ptypYPmdjZKl9lMOUp+piwemv/ee
s9imiuV7DgJ9w/SbKTtJAsTtfruXnqhm+Z8D9SYvO7sajlwUjnstB249tdJf
1rB6uAydE1qZZ2s58lZYbsFlbLrgaj+rjtXHZWg80Vr5hvJ0If0bLyNr4US9
c/WsXnJROmjYnFnUv8eF9F2SCwvfCXqv5ax+clHS0bDijIIjTb5CQHJhkB1k
Z6fkyAGxnvLgdY+LbaVsKSZ4HjJ7q5871sDqKw+Xe4z61uYaR3aenEFTJg/f
ebqZPrjG6u0K9m88mLj3X44ohogBxvyO8PIx11n9XUGl3fk1SsqDBfu/vIKn
E8+d3XKD1WM+1jvGO/a/yZENQnl45WNba0dQ4U1Wn/lwd4lzW0H7TZEQ3f/y
wdt2y+lxm9XrVRQ+nhocR5mTChJzAiJ6zGlk9XsVs5X71V5TFq/vw1VoTJ6x
5+gdVs8FeOk//pTlXY6I2/MrQMjcDCvlXVbfBXhzyXrJxnscUROfQmT7mBvy
91m9F8J5zodFqZRjyn6mFV2IL7cGjZ/3gNV/IfokGge9ojyPViO/uxB9by/d
c+gh80EhTBJ8e4xq4sh7ofuUFGL07y3G5U3MD5SVlvnLaf89byIURBFmLnrQ
9vUR80URHH38c8495siPD4UAF8H4Qghn/YT5owj9ufIuBeU30cIGi5Bx6si2
tU+ZT4qw2H3/Ma1mjpwRdldVhFvPZk4538z8UoSx0a4+Ni0cITS5ZusWw7DH
YgdlC/NNMTpJU9bqVo60fBIOXAy1ibtz1J8x/xTDb/Z1x2DKR4vFAobxgk27
LZ9zRNJlMXodeDungrJ4XHkxWm1fpC55wfxUDIcv75PbKYvL8TIof0v9MeAl
85UMiQ2JfgNfcUTU0XwZDtzb65DxivlLhtzsazk/0nlGGh9kOOc2rvjOa+Yz
GfQCLVZ5veGIqIMbMgw7uSqpexvzmww7PbYcP0XZXyhnoxLobHtlMPIt810J
ptWusMmjbCYWUAkWytZ3OfzH/FcCn4mRy+5RrhfHixLYuJxatb6d+bAEVlm3
eLUOjmwRyuEuXX9Ctz+OdjA/lmDQm7BfBr3jyEAhnQeUQrFgZlPyO+bLUvzQ
d5cJOjlSLqSfWynK3zR31nYyf5bCT1Nz6+L3HFkvhPdCKdL2eEQ+e898Wood
8pC/fD5w5Fux4EvR6Gn5QvMj82sZutpSdIIoFwjbG1YG6zFRDQM/Md+Woefb
4JkJlD1WCk8Zjkwy+uO7z8y/ZSBfLg0toSwMT9SwaF5ZfXxuF/NxGZrO9Um8
TVmwo09rGaJutW90/8L8XI6/16g/eU15iTiglmNRXG5336/M1+UY9zm8vrsa
T7REQZWjb4PV7EDKkr/LUZPwzsuwG0+EaOgnleMU7/lDOGXJ5+W4fkar1kyd
J+J097ocA+/PVU+hLPm9Ak5HC5utu/Pki1BulhVoWHZtWwFlyfcVaDbSKrXX
4EmUkM4bKzB6Z31+rQabzytgviXW01mTJ79IB8bHRzpltylL/aAChgXrrrtp
8eSdEI6OCgz+ZlbwU8pSf6jEnWda/NoePAkTjmtdiSG+ZrZtlKV+UYmud8YD
vXvyxF68wEoUJs3L/EhZ6h+VQPfvu/n34skrsT1UQnPt3O7dtXlVP6lExJbO
vL2UTwl6/1SJnrURo7V1eFV/qcKdMcVOgZRtxYBUoX1jgWVfXV7Vb6pQcLpH
5XHKTwW9bq9CVaqmsUFvXtV/qmDbOXTIacqHRf1VYUNB9WOjPjwRdfWwCt7/
uC8NpizqRb0a2Y8XnOn3Da/qT9UIjNQNCKEslu+MajxNfjrZlL6/SP2qGs/6
OYSHUhbLY081LphfkJlyvKp/VSNi+uzIUMpS+lWjRCPazpTnVf2Msk3/kBDK
/wrh7VkDzXu9Mvrp8ar+VgPbwfIDwZS3Cdc3uwYWnnWmxvq8qt/V4Ndflnud
pjxcTMAaxEW/2GlgwN7HajBvV7lTEOXaGvHBXPN5j/oa8qp+WIMfBjdZHaa8
OUgQai3GTLw5U+dbXtUfa9HuechwP2VTMaFrMU97QayGEa/ql7VYEh3UtYNy
qfh6VQtXg9N6XZSl/lmLnzZcfu5jzJN1gk6Vtcge7Li3nbLUT+l6N9MfrTfh
iYFYIHU4EzRZ4zllqb/WIfD82Bb3fjzJF3TgUgfnkBdHHlCW+m0d/t1c9mlh
f564i69fdVi+vveYfylL/bcOLoP0Bs815YmuVHBI9jZvrKAs9eM6xOSELpw+
gCdiupjUY/7e4vA8ylJ/rodF45O4iQN5IoZjcT0Sv3HxS6Qs9et6KG+76Y8Y
xBPp9aweafPnbwqjLPXvenT/7++zhoN5Ii53vx7BJwbtO0xZ6udytPscn6Y1
hNW7HBn2JrnbKEv9XQ5TXXW1jiGs/uUIIEF91g7lVf1ejtZSw6dNQ5kP5DB/
dm2v6zD2/i1HlKdBW/0w5gc5zq8ZONx+OK+aB+Q4E2gz9Mpw5gs5rtyOfW45
glfNB3LMUmZujx7B/CFHo8fFO/3p+7w0L8jxQiND87gZ84kcmgEWH7XMedX8
IMeoeb/mbjVnfpFjyKg19m8oS/OEAtXuaWErRjLfKLCidq3sJmVpvlBAHtOY
4TCK+UeBpqvYVEhZmjcUCHa59cVqNPORAsu/a/ktmrI0fygwNzl+u8kY5icF
HAOWbQqkLM0jCqwz/Xmy2ljmKwVeTo8o30hZmk8UOLw4xuzJWOYvBZKcT7v8
ZsGr5hUF/gxPcK60YD5T4O7UYUOmjuNV84sCxpk2BQnjmN8UWD3UfMyA8bxq
nlFi+dhRq46MZ75T4kNPX281S1413yhxxs/ReYMl858S1g9a1ZsoS/OOEmsG
+O1ymsB8qMS6TNJQPIF936LE2Jz1HROsmB+V+LWetF6kLKbzESUcpjxP4ify
RPr6QAlb+SX7XZSl+UgJ/W7RKW2UpfFRCZ/rw166TeJV85ISFe3On+snMZ8q
wYWsvWc7mVfNT0poxJ4PSpzM/NqAxyeH9+9vzavmqQb4bB3nE2DNfNuA99zb
6PeUpfmqAf8D3St9zg==
        "]]}}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw1mHlcjekbxrP+aCzPGHsM2UkaymTtemgUpURkC1lC2Yosc6YQiYhKkjUt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        "]]}}, {{}, {}}}}, {{
     LineBox[{{2.5017142022180123`, 0.3}, {2.5017142022180123`, 0.29}}], 
     LineBox[{{3.2781729831165154`, 0.3}, {3.2781729831165154`, 0.29}}], 
     LineBox[{{3.7018546632204488`, 0.3}, {3.7018546632204488`, 0.29}}], 
     LineBox[{{3.9712237563246573`, 0.3}, {3.9712237563246573`, 0.29}}], 
     LineBox[{{4.295621817115358, 0.3}, {4.295621817115358, 0.29}}]}, 
    StyleBox[{
      {GrayLevel[0], InsetBox[
        TemplateBox[{"3", "\":\"", "1"},
         "RowDefault"], {2.5017142022180123, 0.285}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}, 
      {GrayLevel[0], InsetBox[
        TemplateBox[{"2", "\":\"", "1"},
         "RowDefault"], {3.2781729831165154, 0.285}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}, 
      {GrayLevel[0], InsetBox[
        TemplateBox[{"5", "\":\"", "3"},
         "RowDefault"], {3.7018546632204488, 0.285}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}, 
      {GrayLevel[0], InsetBox[
        TemplateBox[{"3", "\":\"", "2"},
         "RowDefault"], {3.9712237563246573, 0.285}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}, 
      {GrayLevel[0], InsetBox[
        TemplateBox[{"4", "\":\"", "3"},
         "RowDefault"], {4.295621817115358, 0.285}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times"]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2.4, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"Semi-major Axis (AU)\"", TraditionalForm], 
    FormBox["\"Eccentricity\"", TraditionalForm]},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2.4, 4.7}, {0, 0.3}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8790797842157907`*^9, 3.879081024576124*^9, 3.8790810561870947`*^9, {
   3.879081117086896*^9, 3.879081136796653*^9}, 3.879081425420183*^9, {
   3.879082393381727*^9, 3.8790824181744823`*^9}, 3.879082462816165*^9, 
   3.879096643724023*^9, 3.879327135334906*^9, 3.879327407479135*^9, 
   3.879327566244154*^9, 3.8793277174100113`*^9, {3.879328288159698*^9, 
   3.879328299291421*^9}, {3.879328369389431*^9, 3.879328401985674*^9}, 
   3.879328598333185*^9, 3.879328776675007*^9, 3.890987108280972*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"e1741289-95f8-4226-b019-238d82b37657"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1053, 659},
WindowMargins->{{82, Automatic}, {Automatic, 25}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d5c34bc8-1ae9-4a0a-9689-d13df03503be"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"bf0e32a9-4d4a-4c28-b525-ab29b9afdd91"],
Cell[1000, 31, 108, 0, 67, "Section",ExpressionUUID->"a71c017b-62b1-49b8-ab5c-8e7aaf0a0fd4"],
Cell[1111, 33, 428, 11, 49, "Text",ExpressionUUID->"8a6894a7-971d-43c1-8f65-ad424bf821a8"],
Cell[1542, 46, 318, 7, 33, "Input",ExpressionUUID->"676eeb4c-9ed1-4d0e-912e-c53fc32779c4"],
Cell[1863, 55, 314, 7, 33, "Input",ExpressionUUID->"566e010d-cd36-4f30-bb71-2ae038829cfe"],
Cell[2180, 64, 721, 22, 76, "Text",ExpressionUUID->"1fc8515c-fe1a-4ddf-bdd9-fb617a1bf6a3"],
Cell[2904, 88, 823, 20, 94, "Input",ExpressionUUID->"ccb4d648-554d-4faa-8d2f-f306288f052f"],
Cell[CellGroupData[{
Cell[3752, 112, 144, 2, 30, "Input",ExpressionUUID->"2df5d603-6142-4dbb-84f8-b6efa9274a8f"],
Cell[3899, 116, 931, 26, 79, "Output",ExpressionUUID->"0c9c6d5c-c355-4033-9d04-4a6ee026614c"]
}, Open  ]],
Cell[4845, 145, 209, 5, 53, "Text",ExpressionUUID->"bc4f5443-dd6b-4d84-84be-d9c6b52c360f"],
Cell[5057, 152, 592, 14, 73, "Input",ExpressionUUID->"60640f2d-2c31-4d60-ad33-4c8bca8fc4b5"],
Cell[CellGroupData[{
Cell[5674, 170, 145, 2, 30, "Input",ExpressionUUID->"9053de2c-c131-4f27-91b6-4881ecefff1f"],
Cell[5822, 174, 797, 21, 63, "Output",ExpressionUUID->"c0f47ea9-eb67-4f65-ad00-68490bc46193"]
}, Open  ]],
Cell[6634, 198, 388, 14, 53, "Text",ExpressionUUID->"18b5b74b-89d0-422f-a4b8-51be14f8393c"],
Cell[7025, 214, 4465, 118, 325, "Input",ExpressionUUID->"a6ac6436-de02-45c4-bafd-94219fc5517e"],
Cell[11493, 334, 237, 6, 53, "Text",ExpressionUUID->"58546064-1781-4419-b61c-a03b3c736324"],
Cell[CellGroupData[{
Cell[11755, 344, 341, 7, 30, "Input",ExpressionUUID->"8b97393a-8b50-4158-9d28-ccedaf0ddd5d"],
Cell[12099, 353, 13195, 254, 251, "Output",ExpressionUUID->"111fe7d2-cde3-4d6b-ad59-125709f1f65d"]
}, Open  ]],
Cell[25309, 610, 173, 3, 53, "Text",ExpressionUUID->"c47d9196-1484-428b-a8c5-8b8dd4cecfd3"],
Cell[CellGroupData[{
Cell[25507, 617, 337, 7, 30, "Input",ExpressionUUID->"9d323f40-3bfd-464d-ba73-a92a199557c7"],
Cell[25847, 626, 13177, 253, 251, "Output",ExpressionUUID->"4817b0b0-42ed-40b9-b7a7-229d60a77da4"]
}, Open  ]],
Cell[39039, 882, 152, 3, 53, "Text",ExpressionUUID->"c8dacd4f-9e35-4976-9a6d-7ad77922a08c"],
Cell[CellGroupData[{
Cell[39216, 889, 340, 7, 30, "Input",ExpressionUUID->"6844621b-0d64-4b36-be97-213a4b348464"],
Cell[39559, 898, 13163, 253, 251, "Output",ExpressionUUID->"d263a809-e96a-4e6f-8888-0450375b01a1"]
}, Open  ]],
Cell[52737, 1154, 249, 7, 53, "Text",ExpressionUUID->"17ffc0b3-27b0-490f-9b92-d34f770bb822"],
Cell[52989, 1163, 3214, 85, 241, "Input",ExpressionUUID->"fe52e49f-f573-455d-bd01-f38f688802a6"],
Cell[56206, 1250, 183, 3, 53, "Text",ExpressionUUID->"9d270fd6-51d9-43e5-bee3-ae09ad0e0198"],
Cell[CellGroupData[{
Cell[56414, 1257, 344, 7, 30, "Input",ExpressionUUID->"b08124cb-f5ae-41c8-b8cc-36bff68dd990"],
Cell[56761, 1266, 12818, 247, 251, "Output",ExpressionUUID->"40004610-6f65-4d7d-8231-0b5ee4621b25"]
}, Open  ]],
Cell[69594, 1516, 152, 3, 53, "Text",ExpressionUUID->"b3c8fb06-b4a4-4520-9c7e-8498029db7f9"],
Cell[CellGroupData[{
Cell[69771, 1523, 342, 7, 30, "Input",ExpressionUUID->"d2ee28b1-eab7-4101-aa6c-539bd2b40dc0"],
Cell[70116, 1532, 13245, 254, 251, "Output",ExpressionUUID->"d15afeaf-d1bf-4a3d-9b77-ff672a68e806"]
}, Open  ]],
Cell[83376, 1789, 508, 10, 53, "Text",ExpressionUUID->"91260320-d68b-47f3-9e23-d7f9905789f5"],
Cell[CellGroupData[{
Cell[83909, 1803, 575, 12, 30, "Input",ExpressionUUID->"acdaca2b-a2dd-46c6-8566-8f887068d58a"],
Cell[84487, 1817, 359, 5, 34, "Output",ExpressionUUID->"8ec59d34-24af-4c0f-b710-ec57d6e20a9d"]
}, Open  ]],
Cell[84861, 1825, 489, 10, 53, "Text",ExpressionUUID->"43620af5-0444-4077-9f8d-0ec50f76efd2"],
Cell[85353, 1837, 492, 12, 30, "Input",ExpressionUUID->"c2430dd3-566b-447f-b5a0-768482e46073"],
Cell[85848, 1851, 445, 7, 53, "Text",ExpressionUUID->"7f390734-83a8-43bd-b47d-2a9fe86d6f82"],
Cell[86296, 1860, 529, 13, 30, "Input",ExpressionUUID->"52cb5bf8-b18c-4abd-a07d-879945d0b0b2"],
Cell[86828, 1875, 466, 9, 53, "Text",ExpressionUUID->"233fc2fe-d456-42ee-98eb-ea9fb89d0406"],
Cell[CellGroupData[{
Cell[87319, 1888, 418, 7, 30, "Input",ExpressionUUID->"5f28e515-cfb3-4e14-bf8c-8312f07ffd7d"],
Cell[87740, 1897, 744, 14, 34, "Output",ExpressionUUID->"d80108ca-e92e-483a-a0ef-353b0310a027"]
}, Open  ]],
Cell[88499, 1914, 489, 10, 53, "Text",ExpressionUUID->"052ba23a-3b69-4e29-a094-022129aef0b3"],
Cell[88991, 1926, 1180, 24, 30, "Input",ExpressionUUID->"8317e7b7-c193-4bb0-aff9-e2a1906a91fa"],
Cell[90174, 1952, 520, 10, 53, "Text",ExpressionUUID->"475bc4ef-3615-437a-a97f-96ca954c67d4"],
Cell[90697, 1964, 3512, 85, 178, "Input",ExpressionUUID->"69e5fd73-5d0b-4824-bd72-0234de337c59"],
Cell[94212, 2051, 491, 8, 53, "Text",ExpressionUUID->"8954b9d2-151f-43d9-87ea-1f5bf802a78f"],
Cell[94706, 2061, 1236, 24, 30, "Input",ExpressionUUID->"cfe516a6-24c4-48bc-a81e-67ffd45c6c09"],
Cell[95945, 2087, 656, 10, 53, "Text",ExpressionUUID->"016bf37a-0a82-4bf5-b24d-9d4e816c98a9"],
Cell[96604, 2099, 489, 9, 52, "Input",ExpressionUUID->"feca2ea0-92f4-4127-a038-e9f84722857d"],
Cell[97096, 2110, 342, 8, 53, "Text",ExpressionUUID->"58a9e2a8-3815-41a1-b2a1-5761ec077f67"],
Cell[CellGroupData[{
Cell[97463, 2122, 2072, 42, 115, "Input",ExpressionUUID->"c4de6d64-0cc9-4ae8-a84c-c3fba4b5f453"],
Cell[99538, 2166, 53771, 935, 279, "Output",ExpressionUUID->"e1741289-95f8-4226-b019-238d82b37657"]
}, Open  ]]
}
]
*)

